@@ -1,5 +1,3 @@
-/* $Xorg: session.c,v 1.5 2001/02/09 02:05:37 xorgcvs Exp $ */
-/* $XdotOrg: app/twm/src/session.c,v 1.3 2005/07/16 22:07:13 alanc Exp $ */
 /******************************************************************************
 
 Copyright 1994, 1998  The Open Group
@@ -26,7 +24,6 @@ in this Software without prior written authorization from The Open Group.
 
 Author:  Ralph Mor, X Consortium
 ******************************************************************************/
-/* $XFree86: xc/programs/twm/session.c,v 3.8 2001/12/14 20:01:10 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -53,7 +50,7 @@ Author:  Ralph Mor, X Consortium
 #endif
 #endif
 #endif /* PATH_MAX */
-#ifdef HAS_MKSTEMP
+#ifdef HAVE_MKSTEMP
 #include <unistd.h>
 #endif
 
@@ -74,7 +71,7 @@ Bool sent_save_done = 0;
 
 #define SAVEFILE_VERSION 2
 
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
 static char *unique_filename ( char *path, char *prefix );
 #else
 static char *unique_filename ( char *path, char *prefix, int *pFd );
@@ -116,7 +113,7 @@ Window window;
 	if (prop)
 	    XFree (prop);
     }
-    
+
     return client_id;
 }
 
@@ -358,7 +355,7 @@ char *windowRole;
 	    if (!write_counted_string (configFile, theWindow->name))
 		return 0;
 	}
-    
+
 	wm_command = NULL;
 	wm_command_count = 0;
 	XGetCommand (dpy, theWindow->w, &wm_command, &wm_command_count);
@@ -453,11 +450,11 @@ ReadWinConfigEntry (FILE *configFile, unsigned short version,
 	    goto give_up;
 	if (!read_counted_string (configFile, &entry->wm_name))
 	    goto give_up;
-    
+
 	if (!read_byte (configFile, &byte))
 	    goto give_up;
 	entry->wm_command_count = byte;
-	
+
 	if (entry->wm_command_count == 0)
 	    entry->wm_command = NULL;
 	else
@@ -537,7 +534,7 @@ give_up:
     }
     if (entry->wm_command)
 	free ((char *) entry->wm_command);
-    
+
     free ((char *) entry);
     *pentry = NULL;
 
@@ -554,7 +551,7 @@ char *filename;
     FILE *configFile;
     TWMWinConfigEntry *entry;
     int done = 0;
-    unsigned short version;
+    unsigned short version = 0;
 
     configFile = fopen (filename, "rb");
     if (!configFile)
@@ -720,7 +717,7 @@ Bool *height_ever_changed_by_user;
 
 
 
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
 static char *
 unique_filename (path, prefix)
 char *path;
@@ -734,14 +731,14 @@ int *pFd;
 #endif
 
 {
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
 #ifndef X_NOT_POSIX
     return ((char *) tempnam (path, prefix));
 #else
     char tempFile[PATH_MAX];
     char *tmp;
 
-    sprintf (tempFile, "%s/%sXXXXXX", path, prefix);
+    snprintf (tempFile, sizeof(tempFile), "%s/%sXXXXXX", path, prefix);
     tmp = (char *) mktemp (tempFile);
     if (tmp)
     {
@@ -752,13 +749,13 @@ int *pFd;
     else
 	return (NULL);
 #endif
-#else 
+#else
     char tempFile[PATH_MAX];
     char *ptr;
 
-    sprintf (tempFile, "%s/%sXXXXXX", path, prefix);
+    snprintf (tempFile, sizeof(tempFile), "%s/%sXXXXXX", path, prefix);
     ptr = (char *)malloc(strlen(tempFile) + 1);
-    if (ptr != NULL) 
+    if (ptr != NULL)
     {
 	strcpy(ptr, tempFile);
 	*pFd =  mkstemp(ptr);
@@ -789,7 +786,7 @@ SmPointer clientData;
     char discardCommand[80];
     int numVals, i;
     static int first_time = 1;
-#ifdef HAS_MKSTEMP
+#ifdef HAVE_MKSTEMP
     int fd;
 #endif
 
@@ -805,21 +802,21 @@ SmPointer clientData;
 	prop1val.value = Argv[0];
 	prop1val.length = strlen (Argv[0]);
 
-	sprintf (userId, "%ld", (long)getuid());
+	snprintf (userId, sizeof(userId), "%ld", (long)getuid());
 	prop2.name = SmUserID;
 	prop2.type = SmARRAY8;
 	prop2.num_vals = 1;
 	prop2.vals = &prop2val;
 	prop2val.value = (SmPointer) userId;
 	prop2val.length = strlen (userId);
-	
+
 	prop3.name = SmRestartStyleHint;
 	prop3.type = SmCARD8;
 	prop3.num_vals = 1;
 	prop3.vals = &prop3val;
 	prop3val.value = (SmPointer) &hint;
 	prop3val.length = 1;
-	
+
 	props[0] = &prop1;
 	props[1] = &prop2;
 	props[2] = &prop3;
@@ -836,7 +833,7 @@ SmPointer clientData;
 	if (!path)
 	    path = ".";
     }
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
     if ((filename = unique_filename (path, ".twm")) == NULL)
 	goto bad;
 
@@ -845,8 +842,8 @@ SmPointer clientData;
 #else
     if ((filename = unique_filename (path, ".twm", &fd)) == NULL)
 	goto bad;
-    
-    if (!(configFile = fdopen(fd, "wb"))) 
+
+    if (!(configFile = fdopen(fd, "wb")))
 	goto bad;
 #endif
 
@@ -881,7 +878,7 @@ SmPointer clientData;
 	    }
 	}
     }
-    
+
     prop1.name = SmRestartCommand;
     prop1.type = SmLISTofARRAY8;
 
@@ -924,7 +921,7 @@ SmPointer clientData;
 
     prop1.num_vals = numVals;
 
-    sprintf (discardCommand, "rm %s", filename);
+    snprintf (discardCommand, sizeof(discardCommand), "rm %s", filename);
     prop2.name = SmDiscardCommand;
     prop2.type = SmARRAY8;
     prop2.num_vals = 1;
